Raised when a NIF function is not yet implemented.
This error is temporary during development and will be removed once all C++ bindings are complete.
Raised when a NIF function is not yet implemented.
This error is temporary during development and will be removed once all C++ bindings are complete.